@@ -8,7 +8,7 @@ import sys
 import unittest
 sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 
-from youtube_dlc.options import _hide_login_info
+from yt_dlp.options import _hide_login_info
 
 
 class TestOptions(unittest.TestCase):
